@@ -523,8 +523,11 @@ class Model:
                 name in self.__class__._INDEXES:
                 key_index = key_indexes + name
                 if value != None:
-                    pipe.zadd(key_index, self.__class__._score(value),
-                              str(self._id))
+                    # A bug with redis-py. Some time the form ``member, score``
+                    # is reversed. So we use a ``dict`` here for the form
+                    # ``member=score``.
+                    pipe.zadd(key_index,
+                              **{str(self._id): self.__class__._score(value)})
                 else:
                     pipe.zrem(key_index, str(self._id))
 
